@@ -1,19 +1,22 @@
 #[cfg(target_os = "windows")]
 fn build_winapi() {
     windows::build!(
-        Windows::Foundation::{TypedEventHandler, EventRegistrationToken},
+        Windows::Foundation::{TypedEventHandler, EventRegistrationToken, Uri},
         Windows::Media::{
             SystemMediaTransportControls,
             SystemMediaTransportControlsDisplayUpdater,
             SystemMediaTransportControlsButton,
             SystemMediaTransportControlsButtonPressedEventArgs,
+            SystemMediaTransportControlsTimelineProperties,
             ISystemMediaTransportControls,
             MediaPlaybackType,
             MediaPlaybackStatus,
             MusicDisplayProperties,
+            PlaybackPositionChangeRequestedEventArgs,
         },
-        Windows::Win32::WindowsAndMessaging::HWND,
-        Windows::Win32::MediaTransport::ISystemMediaTransportControlsInterop,
+        Windows::Win32::Foundation::HWND,
+        Windows::Win32::System::WinRT::ISystemMediaTransportControlsInterop,
+        Windows::Storage::Streams::RandomAccessStreamReference,
     );
 }
 
